Crate ranim

Crate ranim 

Ranim is an animation engine written in rust based on wgpu, inspired by 3b1b/manim and jkjkil4/JAnim.

Coordinate System

Ranim’s coordinate system is right-handed coordinate:

     +Y
     |
     |
     +----- +X
   /
+Z

Re-exports

pub use ranim_core::glam;
pub use ranim_core::inventory;

Modules

animsanims
Ranim’s built-in animations
cmd
Commands like preview and render
color
Color Color
core
The core of ranim.
itemsitems
Ranim’s built-in items
prelude
The preludes
renderrender
Rendering stuff Rendering stuff in ranim
utils
Utils

Structs

Output
The output of a scene
RanimScene
The main struct that offers the ranim’s API, and encodes animations The rabjects insert to it will hold a reference to it, so it has interior mutability
SceneConfig
Scene config

Traits

SceneConstructor
A scene constructor