Ranim is an animation engine written in rust based on wgpu, inspired by 3b1b/manim and jkjkil4/JAnim.
Coordinate System
Ranim’s coordinate system is right-handed coordinate:
+Y
|
|
+----- +X
/
+ZRe-exports
Modules
- anims
anims - Ranim’s built-in animations
- cmd
- Commands like preview and render
- color
- Color Color
- core
- The core of ranim.
- items
items - Ranim’s built-in items
- prelude
- The preludes
- render
render - Rendering stuff Rendering stuff in ranim
- utils
- Utils
Structs
- Output
- The output of a scene
- Ranim
Scene - The main struct that offers the ranim’s API, and encodes animations The rabjects insert to it will hold a reference to it, so it has interior mutability
- Scene
Config - Scene config
Traits
- Scene
Constructor - A scene constructor